==> FisicaLab-0.2.2.tar.gz: FisicaLab-0.2.2/AppController.h <==
/* 
   Project: FísicaLab

   Copyright (C) 2009, 2010, 2011 Free Software Foundation

   Author: German A. Arias <german@xelalug.org>

   Created: 2008-09-10 18:56:00 -0600 by german
   
   Application Controller

   This application is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 3 of the License, or (at your option) any later version.
 
   This application is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
*/
 
#ifndef _PCAPPPROJ_APPCONTROLLER_H
#define _PCAPPPROJ_APPCONTROLLER_H

#import <AppKit/AppKit.h>

@interface AppController : NSObject
{
  id elementos;
  id panelAyuda;
  id si;
  id ingles;
  id sistema;
  id pizarra;
}

+ (void)initialize;

- (id)init;
- (void)dealloc;

- (void)awakeFromNib;

- (void)applicationWillFinishLaunching: (NSNotification *)aNotification;
- (void)applicationDidFinishLaunching:(NSNotification *)aNotif;
- (BOOL)applicationShouldTerminate:(id)sender;
- (void)applicationWillTerminate:(NSNotification *)aNotif;

- (void)showPrefPanel:(id)sender;
- (void)ayuda: (id)sender;
- (void)moduloSel: (id)sender;

- (void)windowWillClose: (NSNotification *)aNotification;

@end

#endif

==> FisicaLab-0.3.0.tar.gz: FisicaLab-0.3.0/AppController.h <==
/* 
   Copyright (C) 2009, 2010, 2011, 2012 German A. Arias <german@xelalug.org>

   This file is part of FísicaLab application

   This application is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 3 of the License, or (at your option) any later version.
 
   This application is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
 
   You should have received a copy of the GNU General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
*/
 
#ifndef _PCAPPPROJ_APPCONTROLLER_H
#define _PCAPPPROJ_APPCONTROLLER_H

#import <AppKit/AppKit.h>

@interface AppController : NSObject
{
  id elementos;
  id panelAyuda;
  id unitsSelector;
  id sistema;
  id pizarra;
  id staticRigidBodies;
  id staticRigidBodiesView;
  id dynamicsCircularParticles;
  id dynamicsCircularParticlesView;

  //Preferences panel
  NSPanel *preferencesPanel;
  id widthLabel;
  id heightLabel;
  id fontsizeLabel;
  id widthStepper;
  id heightStepper;
  id fontsizeStepper;
}

+ (void)initialize;

- (id)init;
- (void)dealloc;

- (void)awakeFromNib;

- (void)applicationWillFinishLaunching: (NSNotification *)aNotification;
- (void)applicationDidFinishLaunching:(NSNotification *)aNotif;
- (BOOL)applicationShouldTerminate:(id)sender;
- (void)applicationWillTerminate:(NSNotification *)aNotif;

- (void)showPrefPanel:(id)sender;
- (void)ayuda: (id)sender;
- (void)moduloSel: (id)sender;

- (void)addToChalkboard: (id)sender;

- (void)windowWillClose: (NSNotification *)aNotification;

// Preferences
- (void) changeChalkboardWidth: (id)sender;
- (void) changeChalkboardHeight: (id)sender;
- (void) changeFontsizeTooltips: (id)sender;
- (void) restoreDefaults: (id)sender;

@end

#endif
